@@ -124,12 +124,13 @@ def pre_install():
         raise
 
 def post_install():
-    print("")
-    print("Starting config.")
-
-    from pbclient.prefs import Prefs
-    Prefs().load_from_console()
-
+# Is not visible when invoked from within Setuptools.
+#    print("")
+#    print("Starting config.")
+#
+#    from pbclient.prefs import Prefs
+#    Prefs().load_from_console()
+#
     print("Installing crontab job.")
     _crontab_config.install()
 
