@@ -8,7 +8,7 @@
 
 from sys import stderr
 
-_out = stderr
+_out = stdout
 
 class PromptAbortException(Exception):
     pass
